GCbiasRemoval <-
function(input, GCcontent){
### Written by Mengjie Chen, Nov 2012 ####	
### This method is modified from Diskin et al. Adjustment of genomic waves in signal intensities from whole-genome SNP genotyping platforms. Nucleic Acids Research, 36(19):e126, 2008. 	
	if(class(input) != "GRanges")
		stop("Wrong input format! Check the manual")
  x <- as.data.frame(input, row.names = NULL, optional = FALSE) 
	tumor.med <- median(x$tCount)
	normal.med <- median(x$tCountN)
	x$tumorR <- x$tCount/tumor.med	
  x$normalR <-x$tCountN/normal.med
  binsize <- GCcontent$interval1[2]-GCcontent$interval1[1]
	x$ID <- paste(x[, 1], floor(x[, 2]/binsize), sep=";")
	GCcontent$ID <- paste(GCcontent$chr, floor(GCcontent$interval1/binsize), sep=";")
	final <- merge(x, GCcontent, by.x="ID", by.y="ID")
	sub <- final[sort(sample(1:length(final$tumorR), round(length(final$tumorR)/10), replace=F)), ]
	dis <- c(0, sub$start[-1]-sub$start[-length(sub$start)])
	far <- sub[dis > 10000 & !sub$seqnames%in%c("chrX", "chrY", "chrM") 
             & sub$LAF>0.4 & sub$tumorR < 1.25 & sub$tumorR > 0.8 & sub$normalR< 1.25 
             & sub$normalR> 0.8 & sub$GC!=0, ]
	lm.far <- lm((far$tumorR-1)~far$GC)
	final$tRcorrected <- final$tumorR - lm.far$coefficients[2]*final$GC- lm.far$coefficients[1]	
	lm.far2 <- lm((far$normalR-1)~far$GC)
	final$nRcorrected <- final$normalR - lm.far2$coefficients[2]*final$GC- lm.far2$coefficients[1]
	
  result <- GRanges(seqnames=final$seqnames, 
                  ranges=IRanges(start=final$start, width=1),
                  zygosity=final$zygosity,
                  tCount=final$tCount,
                  LAF=final$LAF,
                  tCountN=final$tCountN, 
                  germLAF=final$germLAF,
                  tRcorrected=final$tRcorrected, 
                  nRcorrected=final$nRcorrected)  
	return(result)
}
