SomatiCApipe <- function(input, ncores = 1, collapse.k = 0, method = "mle", 
                mcmc = 50000, burnin = 10000, p = 0.001, verbose = TRUE, 
                rss = FALSE, adjust=TRUE, threshold1 = 0.01, threshold2 = 0.05, S = 0.1, GC, 
                set.admix = NULL, ...){
### Written by Mengjie Chen, Nov 2012 ###
### Last time updated, Jan 2013 ###  
### SomatiCA pipeline ###	

		if(ncores > 1){
		  suppressPackageStartupMessages(require(doParallel))
		  registerDoParallel(ncores)
		}
		if(!is.null(set.admix)){
		  if(set.admix>1 & set.admix<0) stop("Invalid admixture rate.")
		}     
		if(verbose==TRUE) message("Running segmentation...")
		z <- larsCBSsegment(input, collapse.k = collapse.k, ncores = ncores, verbose = verbose, rss = rss, S = S, ...)
		if(verbose==TRUE) message("Estimating somatic ratio...")
		segmentwithRatio <- somaticRatio(z$segment, input, method = method, adjust = adjust) 
		if(verbose==TRUE) message("Refining segmentation...")
		refined <- refineSegment(segmentwithRatio, input, method = method, adjust = adjust, threshold1 = threshold1 , threshold2 = threshold2) 		
    if(verbose==TRUE) message("Estimating admixture rate...")
		x <- admixtureRate(refined, mcmc = mcmc, burnin = burnin, p = p) 
		admix <- x$admix
		if(verbose==TRUE) message("Estimating subclonality...")
    if(!is.null(set.admix)) admix <- set.admix
		y <- copynumberCorrected(segmentwithRatio, admix)
		segmentGCcorrected <- segmentGCbiasRemoval(y, input, GC)
		segmentClonality <- subclonality(segmentGCcorrected, admix)
		results <- list(admix = admix, segment = segmentClonality)
		return(results)
	}
