plotSegment <-
function (segment, input, k = 1, col1 = "orange", col2 = "blue", smooth = FALSE, dev.new = TRUE, ...) 
{
### Written by Mengjie Chen, Nov 2012 ####
### Modified, Dec 2012 ####
### Visualization of segmentation for each chromosome ###	
  if(class(segment) != "GRanges" | class(input) != "GRanges")
  stop("Wrong input! Please check the manuals.")
  input <- as.data.frame(input)
  segment <- as.data.frame(segment)
	hetersites <- input[grep("het", input$zygosity), ]
	chr <- as.character(unique(hetersites$seqnames)[k])
	data <- hetersites$LAF[hetersites$seqnames==chr]
	if(smooth == TRUE) {
		message("Showing smoothed data. May take a while for denoising.")
		data <- denoise(data, k = 50)
	}
	else message("Showing input data. Caution: SomatiCA uses smoothed data.")
	boundaries <- c(1:length(data))[hetersites$start[hetersites$seqnames==chr] %in% 
                                    segment$end[segment$seqnames==chr]]
  start <- c(0, boundaries[-length(boundaries)])
  end <- boundaries
  k <- length(start)
  ave <- tapply(1:k, 1:k, function(i) {
      median(data[start[i]:end[i]], na.rm=TRUE)
  })
  if(dev.new==TRUE)  dev.new(width = 12, height = 6)
  plot(data, pch = 20, ylim = c(min(data, na.rm=TRUE), max(data, na.rm=TRUE)), xlim = c(0, 
        length(data)), cex = 0.5, col = col1, axes = F, xlab="", ylab="LAF", cex.lab=1.3, main = chr, ...)
  axis(2)
  for (i in 1:length(start)) 
    lines(c(start[i], end[i]), c(ave[i], ave[i]), col = col2, lwd = 4)
}
