segmentGCbiasRemoval <-
function(segment, input, GC, remove=TRUE){
### Written by Mengjie Chen, Nov 2012 ###
### Last time update, Jan 2013  
### Calculation of GC corrected read depth ratio(read depth/median) for both normal and tumor sample ###   	
	if(class(input) != "GRanges" | class(segment) != "GRanges")
		stop("Wrong input format! Check the manual!")
  if(remove==TRUE){
	  GCcorrected <- GCbiasRemoval(input, GC)
	  GCcorrected <- as.data.frame(GCcorrected, stringsAsFactors=FALSE)
  }
  else{
    tumor.med <- median(input$tCount)
    normal.med <- median(input$tCountN)
    GCcorrected <- as.data.frame(input, stringsAsFactors=FALSE)
    GCcorrected$tRcorrected <- GCcorrected$tCount/tumor.med	
    GCcorrected$nRcorrected <- GCcorrected$tCountN/normal.med
  }
	suppressPackageStartupMessages(require(foreach))
  segment <- as.data.frame(segment, stringsAsFactors=FALSE)
  i <- NULL
	results <- foreach(i=1:length(segment$ratio), .combine=rbind) %do% { 	
		tumorsub <- GCcorrected$tRcorrected[GCcorrected$start < segment$end[i]
                                      & GCcorrected$start >= segment$start[i] 
                                      & as.character(GCcorrected$seqnames) == as.character(segment$seqnames[i])]	
		normalsub <- GCcorrected$nRcorrected[GCcorrected$start < segment$end[i]
		                                     & GCcorrected$start >= segment$start[i] 
		                                     & as.character(GCcorrected$seqnames) == as.character(segment$seqnames[i])]  
		aa <- tumorsub[tumorsub>0]
		bb <- normalsub[normalsub>0]
		a <- round(exp(sum(log(aa))/length(aa)), 3)
		b <- round(exp(sum(log(bb))/length(bb)), 3)
		return(c(a, b))
	}	

  final <- GRanges(seqnames=segment$seqnames, 
	                  ranges=IRanges(start=segment$start, end=segment$end),
	                  medLAF=segment$medLAF,
	                  medgLAF=segment$medgLAF,
	                  ratio=segment$ratio,
	                  somaCN=segment$somaCN, 
	                  event=segment$event,
	                  tRcorrected=as.numeric(results[, 1]),
	                  nRcorrected=as.numeric(results[, 2]))  
  return(final)	
}