\name{GCbiasRemoval}
\alias{GCbiasRemoval}
\title{
Correct GC bias for read depth ratio of each site. 
}
\description{
Read depth ratio is defined as read depth at each site divided by median of read depth of that sequencing library. SomatiCA corrects GC bias for read depth ratio at each site based on a linear model described in Diskin et al.(2008). 
}
\usage{
GCbiasRemoval(input, GCcontent)
}

\arguments{
  \item{input}{
A GRanges object. Same as the output of SomatiCAFormat().
}
  \item{GCcontent}{
A data frame object with 4 column."chr", "interval1", "interval2" and "GC".
}
}

\value{
A GRanges object.
\item{zygosity, tCount, LAF, tCountN, germLAF}{Same as the outout SomatiCAFormat()}
\item{tRcorrected}{GC bias corrected read depth ratio for tumor sample.}
\item{nRcorrected}{GC bias corrected read depth ratio for normal sample. }

}
\references{
Diskin et al. Adjustment of genomic waves in signal intensities from whole-genome SNP genotyping platforms. \emph{Nucleic Acids Research}, 36(19):e126, 2008.

}
\author{
Mengjie Chen
}

\seealso{
See Also \code{\link{segmentGCbiasRemoval}}.
}
\examples{
rawLAF <- c(rnorm(300, 0.2, 0.05), rnorm(300, 0.4, 0.05), rnorm(200, 0.3, 0.05), rnorm(200, 0.2, 0.05), rnorm(200, 0.3, 0.05), rnorm(250, 0.4, 0.05)) 
germLAF <- c(rnorm(800+650, 0.4, 0.05)) 
reads1 <- c(rpois(300, 25), rpois(300, 50), rpois(200, 60),  rpois(200, 25), rpois(200, 40), rpois(250, 50))
reads2 <- rpois(800+650, 50)
chr <- c(rep("chr1", 800), rep("chr2", 650))
position <- c(seq(1, 1600000, by=2000), seq(1, 1300000, by=2000))
zygo <- rep("het", 800+650)
data <- GRanges(seqnames=chr, 
        ranges=IRanges(start=position, width=1), 
        zygosity=zygo, 
        tCount=reads1, 
        LAF=rawLAF, 
        tCountN=reads2, 
        germLAF=germLAF) 
data(GCcontent)        
x <- GCbiasRemoval(data, GCcontent)

}

\keyword{methods}

