\name{SomatiCA-package}
\alias{SomatiCA-package}
\alias{SomatiCA}
\docType{package}
\title{
Identifying, characterizing and quantifying somatic copy number aberrations from cancer genome sequencing
}
\description{
SomaticCNA is a software suite that is capable of identifying, characterizing, and quantifying somatic CNAs from cancer genome sequencing. First, it uses read depths and lesser allele frequencies (LAF) from mapped short sequence reads to segment the genome and identify candidate CNAs. Second, SomaticCNA estimates the admixture rate from the relative copy-number profile of tumor-normal pair by a Bayesian finite mixture model. Third, SomaticCNA quantifies absolute somatic copy-number and subclonality for each genomic segment to guide its characterization. 
}
\details{
\tabular{ll}{
Package: \tab SomatiCA\cr
Type: \tab Package\cr
Version: \tab 0.99.1\cr
Date: \tab 2012-11-13\cr
License: \tab GPL (>=2) \cr
}

}
\author{
Mengjie Chen, Hongyu Zhao
Maintainer: Mengjie Chen <mengjie.chen@yale.edu>

}

\keyword{ package }
\seealso{
\code{\link[DNAcopy:segment]{segment}}
}
\examples{
rawLAF <- c(rnorm(300, 0.2, 0.05), rnorm(300, 0.4, 0.05), rnorm(200, 0.3, 0.05), rnorm(200, 0.2, 0.05), rnorm(200, 0.3, 0.05), rnorm(250, 0.4, 0.05)) 
rawLAF <- ifelse(rawLAF>0.5, 1-rawLAF, rawLAF) 
germLAF <- c(rnorm(800+650, 0.4, 0.05)) 
germLAF <- ifelse(germLAF>0.5, 1-germLAF, germLAF) 
reads1 <- c(rpois(300, 25), rpois(300, 50), rpois(200, 60),  rpois(200, 25), rpois(200, 40), rpois(250, 50))
reads2 <- rpois(800+650,50)
chr <- c(rep("chr1", 800), rep("chr2", 650))
position <- c(c(1:800), c(1:650))
zygo <- rep("het", 800+650)
x <- data.frame(chr, as.integer(position), as.character(zygo), as.integer(reads1), rawLAF, as.integer(reads2), germLAF) 
colnames(x) <- c("seqnames", "start", "zygosity", "tCount", "LAF", "tCountN", "germLAF")            
data <- SomatiCAFormat(x)

### This is an easy example, without much noise.
### Consider to use rss=T to select change points from sequencing data
seg <- larsCBSsegment(data, rss = FALSE)

plotSegment(seg$segment, data, k = 2, smooth = FALSE)
}
