\name{admixtureRate}
\alias{admixtureRate}
\title{
Estimate the admixture rate of normal cells in a tumor sample.
}
\description{
The estimation of the admixture rate is accomplished by fitting the input tumor somatic copy number (somatic ratio*2) of all segments with a Bayesian finite mixture model, with components centered at the discrete levels. Each segment was assigned with a discrete level based on corresponding posterior probability. Segments with ambiguous assignments will be classified as candidate subclonal events and excluded from admixture rate inference. The admixture rate will be estimated by an optimal solution contributed by explanation of tumor copy number with all remaining segments as integer level. 
}
\usage{
admixtureRate(segmentwithratio, mcmc = 10000, burnin = 5000, p = 0.01, weight=FALSE)
}
\arguments{
  \item{segmentwithratio}{
A GRanges object, segments with annotation of somatic ratio. 
}
  \item{mcmc}{
number of MCMC iteration.
}
  \item{burnin}{
number of MCMC iteration for burnin.
}
  \item{p}{
posterior probability cutoff for ambiguous integer copy number assignments.
}
  \item{weight}{
whether penalize the segment based on its length.
}
}

\value{

\item{admix}{Admixture rate.}
\item{mu}{Posterior mean for each discrete level.}
\item{cluster}{A two-column matrix for input somatic ratio and corresponding integer somatic copy number level.}

}

\author{
Mengjie Chen
}

\examples{
data(segwithratio)
seg <-  GRanges(seqnames=segwithratio$chromosome, 
              ranges=IRanges(start=segwithratio$start, 
                             end=segwithratio$end),
              medLAF=segwithratio$medLAF,
              medgLAF=segwithratio$medgermlineLAF,
              ratio=segwithratio$ratio)
bb <- admixtureRate(seg)
}

\keyword{methods}

